==> kimageannotator_0.4.0.orig.tar.gz: kImageAnnotator-0.4.0/translations/kImageAnnotator_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>kImageAnnotator::AnnotationContextMenu</name>
    <message>
        <source>Arrange</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bring to Front</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bring Forward</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Send Backward</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Send to Back</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select This</source>
        <translation>Seleziona questo</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copia</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Modifica</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationSettings</name>
    <message>
        <source>Color</source>
        <translation>Colore</translation>
    </message>
    <message>
        <source>Width</source>
        <translation>Larghezza</translation>
    </message>
    <message>
        <source>Text Color</source>
        <translation>Colore del testo</translation>
    </message>
    <message>
        <source>Font Size</source>
        <translation>Dimensione dei caratteri</translation>
    </message>
    <message>
        <source>Starting Number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Obfuscation Factor</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationTabContextMenu</name>
    <message>
        <source>Close</source>
        <translation>Chiudi</translation>
    </message>
    <message>
        <source>Close Other</source>
        <translation>Chiudi altro</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close All to the Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close All to the Right</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::CropWidget</name>
    <message>
        <source>Crop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>W:</source>
        <translation>L:</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>A:</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FillModePicker</name>
    <message>
        <source>Border And Fill Visibility</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Border and Fill</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Border and No Fill</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No Border and No Fill</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ImageEffectPicker</name>
    <message>
        <source>Image Effects</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No Effect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Drop Shadow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Grayscale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Border</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ScaleDialog</name>
    <message>
        <source>Scale Image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Keep Aspect Ratio</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>Larghezza:</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>Altezza:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>Pixel</source>
        <translation>Pixel</translation>
    </message>
    <message>
        <source>Percent</source>
        <translation>Percentuale</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::StickerPicker</name>
    <message>
        <source>Sticker</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ToolPicker</name>
    <message>
        <source>Select</source>
        <translation>Seleziona</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>Penna</translation>
    </message>
    <message>
        <source>Number</source>
        <translation>Numero</translation>
    </message>
    <message>
        <source>Marker Rectangle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Marker Ellipse</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Marker Pen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Testo</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Freccia</translation>
    </message>
    <message>
        <source>Double Arrow</source>
        <translation>Doppia freccia</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Linea</translation>
    </message>
    <message>
        <source>Blur</source>
        <translation>Sfocatura</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Rettangolo</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Ellisse</translation>
    </message>
    <message>
        <source>Number Pointer</source>
        <translation>Puntatore numerico</translation>
    </message>
    <message>
        <source>Sticker</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pixelate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Text Pointer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Text Arrow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Number Arrow</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ZoomIndicator</name>
    <message>
        <source>Zoom Level</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> kimageannotator_0.5.orig.tar.gz: kImageAnnotator-0.5.0/translations/kImageAnnotator_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>kImageAnnotator::AnnotationContextMenu</name>
    <message>
        <source>Arrange</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bring to Front</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bring Forward</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Send Backward</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Send to Back</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select This</source>
        <translation>Seleziona questo</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copia</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Modifica</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationGeneralSettings</name>
    <message>
        <source>General Settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationImageSettings</name>
    <message>
        <source>Image Settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationItemSettings</name>
    <message>
        <source>Color</source>
        <translation type="unfinished">Colore</translation>
    </message>
    <message>
        <source>Text Color</source>
        <translation type="unfinished">Colore del testo</translation>
    </message>
    <message>
        <source>Width</source>
        <translation type="unfinished">Larghezza</translation>
    </message>
    <message>
        <source>Number Seed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Obfuscation Factor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Item Shadow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Item Settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationTabContextMenu</name>
    <message>
        <source>Close</source>
        <translation>Chiudi</translation>
    </message>
    <message>
        <source>Close Other</source>
        <translation>Chiudi altro</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close All to the Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close All to the Right</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationToolSelection</name>
    <message>
        <source>Tool Selection</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::BoolPicker</name>
    <message>
        <source>Enabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::CropWidget</name>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>W:</source>
        <translation>L:</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>A:</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FillModePicker</name>
    <message>
        <source>Border And Fill Visibility</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Border and Fill</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Border and No Fill</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No Border and No Fill</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FontPicker</name>
    <message>
        <source>Font Size</source>
        <translation type="unfinished">Dimensione dei caratteri</translation>
    </message>
    <message>
        <source>Bold</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Italic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Underline</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ImageEffectPicker</name>
    <message>
        <source>Image Effects</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No Effect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Drop Shadow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Grayscale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Border</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invert Color</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ModifyCanvasWidget</name>
    <message>
        <source>Restricted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When enabled enforces the canvas
to include the background image.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>X:</source>
        <translation type="unfinished">X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation type="unfinished">Y:</translation>
    </message>
    <message>
        <source>W:</source>
        <translation type="unfinished">L:</translation>
    </message>
    <message>
        <source>H:</source>
        <translation type="unfinished">A:</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Annulla</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Canvas Background Color</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::RotateDialog</name>
    <message>
        <source>Rotate Image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>180°</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>90° Clockwise</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>90° Counter Clockwise</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Arbitrary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Positive values rotate clockwise, negative values counter clockwise.
Rotating by non 90° multipliers might introduce loss of quality.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Vertical</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished">OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Annulla</translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Flip</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ScaleDialog</name>
    <message>
        <source>Scale Image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Keep Aspect Ratio</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>Larghezza:</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>Altezza:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>Pixel</source>
        <translation>Pixel</translation>
    </message>
    <message>
        <source>Percent</source>
        <translation>Percentuale</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::StickerPicker</name>
    <message>
        <source>Sticker</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ToolPicker</name>
    <message>
        <source>Select</source>
        <translation>Seleziona</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>Penna</translation>
    </message>
    <message>
        <source>Number</source>
        <translation>Numero</translation>
    </message>
    <message>
        <source>Marker Rectangle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Marker Ellipse</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Marker Pen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Testo</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Freccia</translation>
    </message>
    <message>
        <source>Double Arrow</source>
        <translation>Doppia freccia</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Linea</translation>
    </message>
    <message>
        <source>Blur</source>
        <translation>Sfocatura</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Rettangolo</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Ellisse</translation>
    </message>
    <message>
        <source>Number Pointer</source>
        <translation>Puntatore numerico</translation>
    </message>
    <message>
        <source>Sticker</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pixelate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Text Pointer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Text Arrow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Number Arrow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ZoomPicker</name>
    <message>
        <source>Zoom In (%1)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Zoom Out (%1)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reset Zoom (%1)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
